# geopy

Geocoding and coordinate utilities for Swiss and global use cases.

See {doc}`../examples/geopy` for usage examples.

## API Reference

```{eval-rst}
.. automodule:: pyedautils.geopy
   :members:
   :undoc-members:
   :show-inheritance:
```
